first = int()
second = int()

def add(first, second):
	return first + second
	
def multiply(first, second):
	return first * second
	
def divide(first, second):
	return first / second

def substract(first, second):
	return first - second


from setuptools import setup

setup(name='spmmtb',
	  version='3.0',
	  description='Simple math module with: add, substract, multiply, divide only, usage: action(first, second)',
	  packages=['spmmtb'],
	  author='ReGamer45',
	  author_email='t.belf2020@gmail.com',
	  url='https://github.com/ReGamer45/spmmtb',
	  zip_safe=False)